@@ -15,7 +15,6 @@
 // specific language governing permissions and limitations
 // under the License.
 
-// +build !integration
 // +build darwin freebsd linux windows
 
 package network
@@ -23,13 +22,26 @@ package network
 import (
 	"testing"
 
+	"github.com/stretchr/testify/assert"
+
 	mbtest "github.com/elastic/beats/metricbeat/mb/testing"
 )
 
-func TestData(t *testing.T) {
-	f := mbtest.NewEventsFetcher(t, getConfig())
+func TestFetch(t *testing.T) {
+	f := mbtest.NewReportingMetricSetV2(t, getConfig())
+	events, errs := mbtest.ReportingFetchV2(f)
 
-	err := mbtest.WriteEvents(f, t)
+	assert.Empty(t, errs)
+	if !assert.NotEmpty(t, events) {
+		t.FailNow()
+	}
+	t.Logf("%s/%s event: %+v", f.Module().Name(), f.Name(),
+		events[0].BeatEvent("system", "network").Fields.StringToPrint())
+}
+
+func TestData(t *testing.T) {
+	f := mbtest.NewReportingMetricSetV2(t, getConfig())
+	err := mbtest.WriteEventsReporterV2(f, t, ".")
 	if err != nil {
 		t.Fatal("write", err)
 	}
